<template>
  <div class="tree-table-container">
    <div class="drag-box" ref="drag-box">
      <div class="drag-left">
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu"></i> 设备分类目录
          </div>
          <div class="common-tree-content">
            <el-tree highlight-current v-if="treeData.length" :data="treeData" :props="defaultProps"
              @node-click="handleNodeClick" default-expand-all>
              <span class="custom-tree-node" slot-scope="{data}">{{ data.name }}</span>
            </el-tree>
          </div>
        </div>
      </div>
      <div class="drag-resize" title="收缩侧边栏">
        ⋮
      </div>
      <div class="drag-mid">
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                  <el-col :span="5">
                    <el-form-item label="设备名称">
                      <el-input style="width: 100%" clearable placeholder="请输入设备名称" v-model="params.name"
                        maxlength="64"></el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="10">
                    <el-form-item label="查询时间">
                      <el-date-picker style="width: 100%" v-model="searchTime" type="datetimerange" range-separator="至"
                        start-placeholder="开始时间" end-placeholder="结束时间" @change="changeTime">
                      </el-date-picker>
                    </el-form-item>
                  </el-col>
                  <el-col :span="5">
                    <el-form-item label="设备编码">
                      <el-input style="width: 100%" clearable placeholder="请输入设备编码" v-model="params.code"
                        maxlength="32"></el-input>
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
                    </el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset">重置
                    </el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div class="bbsl-table-content" ref="contentPanel">
              <div class="bbsl-btn-content" ref="btnPanel"></div>
              <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
                <el-table-column type="index" width="55" label="序号"></el-table-column>
                <el-table-column min-width="120" prop="deviceCode" label="设备编码" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="140" prop="deviceName" label="设备名称" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="100" prop="deviceType" label="设备类型" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="80" prop="normalTims" label="正常时长" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="80" prop="warnTims" label="告警时长" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="80" prop="faultTims" label="故障时长" show-overflow-tooltip>
                </el-table-column>
                <el-table-column min-width="80" prop="faultRate" label="故障率" show-overflow-tooltip>
                </el-table-column>
              </el-table>
              <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                @size-change="handleSizeChange" @current-change="handleCurrentChange"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total"></el-pagination>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import productType from '@/api/device/productType.js'
import { dragControllerDiv } from '@/mixins/dragControllerDiv'
import performanceAnalysis from '@/api/device/performanceAnalysis.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import moment from 'moment'

export default {
  name: 'DurationAnalysis',
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/device/appraiseInfo/'
      },
      assessTypeList: [], //考核方式字典
      treeData: [
        { code: '', id: '0', name: '设备分类', type: 0, children: [] }
      ],
      defaultProps: {
        children: 'children',
        label: 'name'
      },
      treeNode: {
        code: '',
        id: '0',
        name: '设备分类',
        type: 0,
        children: []
      },
      searchTime: [
        new Date().setTime(new Date().getTime() - 3600 * 1000 * 24 * 7),
        new Date()
      ],
      params: {
        name: '',
        code: '',
        deviceType: '',
        endTime: '',
        startTime: ''
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'code',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceType',
          relation: 'AND',
          value: ''
        }
      ]
    }
  },
  created() {
    this.assessTypeList = dictUtils.getDictItemsFromCache('jxkh-khfs')
    this.getTreen()
    this.params.endTime = moment().format('YYYY-MM-DDTHH:mm:ss')
    this.params.startTime = moment()
      .subtract(7, 'days')
      .format('YYYY-MM-DDTHH:mm:ss')
  },
  mounted() {
    dragControllerDiv()
  },
  methods: {
    // 打开搜索更多
    openMore() {
      this.showMore = !this.showMore
    },
    changeTime(val) {
      this.params.startTime = moment(val[0]).format('YYYY-MM-DDTHH:mm:ss')
      this.params.endTime = moment(val[1]).format('YYYY-MM-DDTHH:mm:ss')
    },
    // 设备组织树查询
    getTreen() {
      productType.AllproductType({ id: '0' }).then((res) => {
        this.treeData[0].children = res.value
        this.$set(this.treeData)
      })
    },
    // 重置
    clearQuerys() {
      this.params.name = ''
      this.params.code = ''
      this.params.deviceType = ''
      this.loadData()
    },
    handleUpdate(row) {
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.params = this.params
      performanceAnalysis.loadTime(this.queryParam, (res) => {
        this.total = res.value.total
        this.tableData = res.value.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleNodeClick(data) {
      this.treeNode = data
      console.log(this.treeNode)
      if (data.id == '0') {
        this.queryParam.params.deviceType = this.treeNode.code
        this.loadData(1)
      } else {
        this.queryParam.params.deviceType = this.treeNode.code
        console.log(this.treeNode.name)
        this.loadData(1)
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.common-tree-container {
  width: 100% !important;
}

.common-tree-container ::v-deep .el-tree {
  border: none;
}
</style>
